==> haskell-rio-orphans-0.1.2.0-306-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-7M5zg35a0L0F36C7bLueN7
key:                  rio-orphans-0.1.2.0-7M5zg35a0L0F36C7bLueN7
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  a48d794ee3fac85a47ac300c6c84066e
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-orphans
hs-libraries:         HSrio-orphans-0.1.2.0-7M5zg35a0L0F36C7bLueN7
depends:
    base-4.16.4.0 exceptions-0.10.4
    fast-logger-3.1.2-Jts0s6pQs9TGtivKJcRjrB
    monad-control-1.0.3.1-ATKYMnkFwQRIHXjVMGqTnF
    monad-logger-0.3.40-CQ5JicFsVVk9TzGUMiGQkj
    resourcet-1.2.6-5BnvDTZXmqJCsWMY1Zflgy
    rio-0.1.22.0-9iSmuFGeWYjFBZ0r0ZA2T3
    transformers-base-0.4.6-LVJhj8dU6PHCItv1DVbZFi
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-orphans-0.1.2.0-318-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-4jxucdxdC2aHPoeBp1UFMv
key:                  rio-orphans-0.1.2.0-4jxucdxdC2aHPoeBp1UFMv
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  594c71c81c304a1e1e3e846047fdc24d
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-orphans
hs-libraries:         HSrio-orphans-0.1.2.0-4jxucdxdC2aHPoeBp1UFMv
depends:
    base-4.16.4.0 exceptions-0.10.4
    fast-logger-3.1.2-AQtkpPEy7zzKpf61wl8oWJ
    monad-control-1.0.3.1-I8GZevPHGG9CaaoPHICfGK
    monad-logger-0.3.40-2U6wkfWu2pa7AyH1VLvETa
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD
    rio-0.1.22.0-CCynOv5jacWCBs6SD5CPpT
    transformers-base-0.4.6-L226RdjYZ7s6DhRd0WmCwN
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
